import React, { useMemo, useCallback } from "react";
import { OnboardingRequestStatusResponse, useCrossMintStatus } from ".";
import { useCrossMintPopup } from "./useCrossMintPopup";
export const CrossMintButton = ({ className, disabled, onClick, style, tabIndex, theme = "dark", collectionTitle, collectionDescription, collectionPhoto, mintTo, emailTo, listingId, ...props }) => {
    const { hideMintOnInactiveClient, status } = useCrossMintStatus();
    const { connecting, connect } = useCrossMintPopup();
    const handleClick = useCallback((event) => {
        if (onClick)
            onClick(event);
        if (!event.defaultPrevented)
            connect(collectionTitle, collectionDescription, collectionPhoto, mintTo, emailTo, listingId);
    }, [onClick]);
    const content = useMemo(() => {
        if (connecting)
            return React.createElement("p", null, "Connecting ...");
        return React.createElement("p", null, "Buy with credit card");
    }, [connecting]);
    if (hideMintOnInactiveClient && status !== OnboardingRequestStatusResponse.ACCEPTED) {
        return null;
    }
    return (React.createElement("button", { className: `client-sdk-button-trigger client-sdk-button-trigger-${theme}`, disabled: disabled, onClick: handleClick, style: { ...style }, tabIndex: tabIndex, ...props },
        React.createElement("img", { className: "client-sdk-button-icon", src: "https://www.crossmint.io/assets/crossmint/logo.png", alt: "Crossmint logo" }),
        content));
};
//# sourceMappingURL=CrossMintButton.js.map